pub struct BlockCompressor { /* private fields */ }Implementations
Sourceimpl BlockCompressor
impl BlockCompressor
pub fn none() -> Self
pub fn lz4() -> Self
pub fn zstd(level: i32) -> Self
pub fn codec(&self) -> CompressionCodec
pub fn compress(&self, data: &[u8]) -> Vec<u8> ⓘ
Sourcepub fn decompress(&self, data: &[u8]) -> AilakeResult<Vec<u8>>
pub fn decompress(&self, data: &[u8]) -> AilakeResult<Vec<u8>>
Decompresses data written by compress with the same codec.
Returns an error on truncated/corrupted input instead of silently substituting the still-compressed bytes as if they were the decompressed payload — a caller has no way to detect corruption if a failed decompress looks like success.